bayespy.inference.vmp.nodes.expfamily.ExponentialFamily.get_riemannian_gradient
===============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.expfamily

.. automethod:: ExponentialFamily.get_riemannian_gradient